@@ -1,4 +1,4 @@
-#ifndef _OPENSWAN_H
+#ifndef _FREESWAN_H
 /*
  * header file for FreeS/WAN library functions
  * Copyright (C) 1998, 1999, 2000  Henry Spencer.
@@ -14,9 +14,9 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
  * License for more details.
  *
- * RCSID $Id: openswan.h,v 1.1.2.1 2004/03/21 05:23:30 mcr Exp $
+ * RCSID $Id: openswan.h,v 1.82 2003/12/10 01:20:01 mcr Exp $
  */
-#define	_OPENSWAN_H	/* seen it, no need to see it again */
+#define	_FREESWAN_H	/* seen it, no need to see it again */
 
 
 
@@ -43,7 +43,7 @@
 
 #endif /* __KERNEL__ */
 
-#include <openswan/ipsec_param.h>
+#include <freeswan/ipsec_param.h>
 
 
 /*
@@ -158,7 +158,7 @@ struct prng {			/* pseudo-random-number-generator guts */
 
 
 /*
- * definitions for user space, taken from openswan/ipsec_sa.h
+ * definitions for user space, taken from freeswan/ipsec_sa.h
  */
 typedef uint32_t IPsecSAref_t;
 
@@ -459,4 +459,4 @@ extern unsigned int pfkey_lib_debug;  /* bits selecting what to report */
 #define LWDNSQ_CMDBUF_LEN      1024
 #define LWDNSQ_RESULT_LEN_MAX  4096
 
-#endif /* _OPENSWAN_H */
+#endif /* _FREESWAN_H */
