@@ -18,7 +18,7 @@
  * Split out from ipsec_init.c version 1.70.
  */
 
-char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.26 2004/02/09 22:07:06 mcr Exp $";
+char ipsec_proc_c_version[] = "RCSID $Id: ipsec_proc.c,v 1.26.2.3 2004/05/01 04:46:26 ken Exp $";
 
 #include <linux/config.h>
 #include <linux/version.h>
@@ -104,6 +104,41 @@ static struct proc_dir_entry *proc_stats_dir     = NULL;
 struct ipsec_birth_reply ipsec_ipv4_birth_packet;
 struct ipsec_birth_reply ipsec_ipv6_birth_packet;
 
+#define DECREMENT_UNSIGNED(X, amount) ((amount < (X)) ? (X)-amount : 0)
+
+
+
+/* ipsec_snprintf: like snprintf except
+ * - size is signed and a negative value is treated as if it were 0
+ * - the returned result is never negative --
+ *   an error generates a "?" or null output (depending on space).
+ *   (Our callers are too lazy to check for an error return.)
+ * 
+ * @param buf String buffer
+ * @param size Size of the string
+ * @param fmt printf string
+ * @param ... Variables to be displayed in fmt
+ * @return int Return code
+ */
+int ipsec_snprintf(char *buf, ssize_t size, const char *fmt, ...)
+{
+       va_list args;
+       int i;
+       size_t possize = size < 0? 0 : size;
+       va_start(args, fmt);
+       i = vsnprintf(buf,possize,fmt,args);
+       va_end(args);
+       if (i < 0) {
+           /* create empty output in place of error */
+           i = 0;
+           if (size > 0) {
+               *buf = '\0';
+           }
+       }
+       return i;
+}
+
+
 IPSEC_PROCFS_DEBUG_NO_STATIC
 int
 ipsec_eroute_get_info(char *buffer, 
@@ -111,7 +146,7 @@ ipsec_eroute_get_info(char *buffer,
 		      off_t offset, 
 		      int length        IPSEC_PROC_LAST_ARG)
 {
-	struct wsbuf w = {buffer, length, offset, 0, 0, 0, 0};
+	struct wsbuf w = {buffer, length, offset, 0, 0};
 
 #ifdef CONFIG_IPSEC_DEBUG
 	if (debug_radij & DB_RJ_DUMPTREES)
@@ -134,10 +169,7 @@ ipsec_eroute_get_info(char *buffer,
 	spin_unlock_bh(&eroute_lock);
 
 	*start = buffer + (offset - w.begin);	/* Start of wanted data */
-	w.len -= (offset - w.begin);			/* Start slop */
-	if (w.len > length)
-		w.len = length;
-	return w.len;
+	return w.len - (offset - w.begin);
 }
 
 IPSEC_PROCFS_DEBUG_NO_STATIC
@@ -147,8 +179,9 @@ ipsec_spi_get_info(char *buffer,
 		   off_t offset,
 		   int length    IPSEC_PROC_LAST_ARG)
 {
+	const int max_content = length > 0? length-1 : 0;
 	int len = 0;
-	off_t pos = 0, begin = 0;
+	off_t begin = 0;
 	int i;
 	struct ipsec_sa *sa_p;
 	char sa[SATOT_BUF];
@@ -166,28 +199,26 @@ ipsec_spi_get_info(char *buffer,
 	
 	spin_lock_bh(&tdb_lock);
 
-
-	
 	for (i = 0; i < SADB_HASHMOD; i++) {
 		for (sa_p = ipsec_sadb_hash[i];
 		     sa_p;
 		     sa_p = sa_p->ips_hnext) {
 			atomic_inc(&sa_p->ips_refcount);
 			sa_len = satot(&sa_p->ips_said, 'x', sa, sizeof(sa));
-			len += sprintf(buffer + len, "%s ",
+			len += ipsec_snprintf(buffer+len, length-len, "%s ",
 				       sa_len ? sa : " (error)");
 
-			len += sprintf(buffer + len, "%s%s%s",
+			len += ipsec_snprintf(buffer+len, length-len, "%s%s%s",
 				       IPS_XFORM_NAME(sa_p));
 
-			len += sprintf(buffer + len, ": dir=%s",
+			len += ipsec_snprintf(buffer+len, length-len, ": dir=%s",
 				       (sa_p->ips_flags & EMT_INBOUND) ?
 				       "in " : "out");
 
 			if(sa_p->ips_addr_s) {
 				addrtoa(((struct sockaddr_in*)(sa_p->ips_addr_s))->sin_addr,
 					0, buf_s, sizeof(buf_s));
-				len += sprintf(buffer + len, " src=%s",
+				len += ipsec_snprintf(buffer+len, length-len, " src=%s",
 					       buf_s);
 			}
 
@@ -205,82 +236,82 @@ ipsec_spi_get_info(char *buffer,
 					  buf_d,
 					  sizeof(buf_d));
 
-				len += sprintf(buffer + len, " policy=%s->%s",
+				len += ipsec_snprintf(buffer+len, length-len, " policy=%s->%s",
 					       buf_s, buf_d);
 			}
 			
 			if(sa_p->ips_iv_bits) {
 				int j;
-				len += sprintf(buffer + len, " iv_bits=%dbits iv=0x",
+				len += ipsec_snprintf(buffer+len, length-len, " iv_bits=%dbits iv=0x",
 					       sa_p->ips_iv_bits);
 
 				for(j = 0; j < sa_p->ips_iv_bits / 8; j++) {
-					len += sprintf(buffer + len, "%02x",
+					len += ipsec_snprintf(buffer+len, length-len, "%02x",
 						       (__u32)((__u8*)(sa_p->ips_iv))[j]);
 				}
 			}
 
 			if(sa_p->ips_encalg || sa_p->ips_authalg) {
 				if(sa_p->ips_replaywin) {
-					len += sprintf(buffer + len, " ooowin=%d",
+					len += ipsec_snprintf(buffer+len, length-len, " ooowin=%d",
 						       sa_p->ips_replaywin);
 				}
 				if(sa_p->ips_errs.ips_replaywin_errs) {
-					len += sprintf(buffer + len, " ooo_errs=%d",
+					len += ipsec_snprintf(buffer+len, length-len, " ooo_errs=%d",
 						       sa_p->ips_errs.ips_replaywin_errs);
 				}
 				if(sa_p->ips_replaywin_lastseq) {
-                                       len += sprintf(buffer + len, " seq=%d",
+                                       len += ipsec_snprintf(buffer+len, length-len, " seq=%d",
 						      sa_p->ips_replaywin_lastseq);
 				}
 				if(sa_p->ips_replaywin_bitmap) {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,0)
-					len += sprintf(buffer + len, " bit=0x%Lx",
+					len += ipsec_snprintf(buffer+len, length-len, " bit=0x%Lx",
 						       sa_p->ips_replaywin_bitmap);
 #else
-					len += sprintf(buffer + len, " bit=0x%x%08x",
+					len += ipsec_snprintf(buffer+len, length-len, " bit=0x%x%08x",
 						       (__u32)(sa_p->ips_replaywin_bitmap >> 32),
 						       (__u32)sa_p->ips_replaywin_bitmap);
 #endif
 				}
 				if(sa_p->ips_replaywin_maxdiff) {
-					len += sprintf(buffer + len, " max_seq_diff=%d",
+					len += ipsec_snprintf(buffer+len, length-len, " max_seq_diff=%d",
 						       sa_p->ips_replaywin_maxdiff);
 				}
 			}
 			if(sa_p->ips_flags & ~EMT_INBOUND) {
-				len += sprintf(buffer + len, " flags=0x%x",
+				len += ipsec_snprintf(buffer+len, length-len, " flags=0x%x",
 					       sa_p->ips_flags & ~EMT_INBOUND);
-				len += sprintf(buffer + len, "<");
+				len += ipsec_snprintf(buffer+len, length-len, "<");
 				/* flag printing goes here */
-				len += sprintf(buffer + len, ">");
+				len += ipsec_snprintf(buffer+len, length-len, ">");
 			}
 			if(sa_p->ips_auth_bits) {
-				len += sprintf(buffer + len, " alen=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " alen=%d",
 					       sa_p->ips_auth_bits);
 			}
 			if(sa_p->ips_key_bits_a) {
-				len += sprintf(buffer + len, " aklen=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " aklen=%d",
 					       sa_p->ips_key_bits_a);
 			}
 			if(sa_p->ips_errs.ips_auth_errs) {
-				len += sprintf(buffer + len, " auth_errs=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " auth_errs=%d",
 					       sa_p->ips_errs.ips_auth_errs);
 			}
 			if(sa_p->ips_key_bits_e) {
-				len += sprintf(buffer + len, " eklen=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " eklen=%d",
 					       sa_p->ips_key_bits_e);
 			}
 			if(sa_p->ips_errs.ips_encsize_errs) {
-				len += sprintf(buffer + len, " encr_size_errs=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " encr_size_errs=%d",
 					       sa_p->ips_errs.ips_encsize_errs);
 			}
 			if(sa_p->ips_errs.ips_encpad_errs) {
-				len += sprintf(buffer + len, " encr_pad_errs=%d",
+				len += ipsec_snprintf(buffer+len, length-len, " encr_pad_errs=%d",
 					       sa_p->ips_errs.ips_encpad_errs);
 			}
 			
-			len += sprintf(buffer + len, " life(c,s,h)=");
+			len += ipsec_snprintf(buffer+len, length-len, " life(c,s,h)=");
 
 			len += ipsec_lifetime_format(buffer + len,
 						     length - len,
@@ -314,10 +345,10 @@ ipsec_spi_get_info(char *buffer,
 			
 			if(sa_p->ips_life.ipl_usetime.ipl_last) { /* XXX-MCR should be last? */
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,0)
-				len += sprintf(buffer + len, " idle=%Ld",
+				len += ipsec_snprintf(buffer+len, length-len, " idle=%Ld",
 					       jiffies / HZ - sa_p->ips_life.ipl_usetime.ipl_last);
 #else
-				len += sprintf(buffer + len, " idle=%lu",
+				len += ipsec_snprintf(buffer+len, length-len, " idle=%lu",
 					       jiffies / HZ - (unsigned long)sa_p->ips_life.ipl_usetime.ipl_last);
 #endif
 			}
@@ -327,11 +358,11 @@ ipsec_spi_get_info(char *buffer,
 			   (sa_p->ips_comp_ratio_dbytes ||
 			    sa_p->ips_comp_ratio_cbytes)) {
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,3,0)
-				len += sprintf(buffer + len, " ratio=%Ld:%Ld",
+				len += ipsec_snprintf(buffer+len, length-len, " ratio=%Ld:%Ld",
 					       sa_p->ips_comp_ratio_dbytes,
 					       sa_p->ips_comp_ratio_cbytes);
 #else
-				len += sprintf(buffer + len, " ratio=%lu:%lu",
+				len += ipsec_snprintf(buffer+len, length-len, " ratio=%lu:%lu",
 					       (unsigned long)sa_p->ips_comp_ratio_dbytes,
 					       (unsigned long)sa_p->ips_comp_ratio_cbytes);
 #endif
@@ -350,55 +381,62 @@ ipsec_spi_get_info(char *buffer,
 				case ESPINUDP_WITH_NON_ESP:
 					natttype_name="nonesp";
 					break;
+				default:
+					natttype_name = "unknown";
+					break;
 				}
 
-				len += sprintf(buffer + len, " natencap=%s",
+				len += ipsec_snprintf(buffer + len, length-len, " natencap=%s",
 					       natttype_name);
 				
-				len += sprintf(buffer + len, " natsport=%d",
+				len += ipsec_snprintf(buffer + len, length-len, " natsport=%d",
 					       sa_p->ips_natt_sport);
 				
-				len += sprintf(buffer + len, " natdport=%d",
+				len += ipsec_snprintf(buffer + len,length-len, " natdport=%d",
 					       sa_p->ips_natt_dport);
 			}
-#endif CONFIG_IPSEC_NAT_TRAVERSAL
+#endif /* CONFIG_IPSEC_NAT_TRAVERSAL */
 				
-			len += sprintf(buffer + len, " refcount=%d",
+			len += ipsec_snprintf(buffer + len,length-len, " refcount=%d",
 				       atomic_read(&sa_p->ips_refcount));
 
-			len += sprintf(buffer + len, " ref=%d",
+			len += ipsec_snprintf(buffer+len, length-len, " ref=%d",
 				       sa_p->ips_ref);
 #ifdef CONFIG_IPSEC_DEBUG
 			if(debug_xform) {
-			len += sprintf(buffer + len, " reftable=%lu refentry=%lu",
+			len += ipsec_snprintf(buffer+len, length-len, " reftable=%lu refentry=%lu",
 				       (unsigned long)IPsecSAref2table(sa_p->ips_ref),
 				       (unsigned long)IPsecSAref2entry(sa_p->ips_ref));
 			}
 #endif /* CONFIG_IPSEC_DEBUG */
 
-			len += sprintf(buffer + len, "\n");
+			len += ipsec_snprintf(buffer+len, length-len, "\n");
 
-			pos = begin + len;
-			if(pos < offset) {
-				len = 0;
-				begin = pos;
-			}
-			if (pos > offset + length) {
-				atomic_dec(&sa_p->ips_refcount);
-				goto done_spi_i;
-			}
-			atomic_dec(&sa_p->ips_refcount);
-		}
-	}
+                        atomic_dec(&sa_p->ips_refcount);   
+                       
+                        if (len >= max_content) {
+                               /* we've done all that can fit -- stop loops */
+                               len = max_content;      /* truncate crap */
+                                goto done_spi_i;
+                        } else {
+                               const off_t pos = begin + len;  /* file position of end of what we've generated */
 
- done_spi_i:	
+                               if (pos <= offset) {
+                                       /* all is before first interesting character:
+                                        * discard, but note where we are.
+                                        */
+                                       len = 0;
+                                       begin = pos;
+                               }
+                        }
+                }
+        }
+
+done_spi_i:	
 	spin_unlock_bh(&tdb_lock);
 
 	*start = buffer + (offset - begin);	/* Start of wanted data */
-	len -= (offset - begin);			/* Start slop */
-	if (len > length)
-		len = length;
-	return len;
+	return len - (offset - begin);
 }
 
 IPSEC_PROCFS_DEBUG_NO_STATIC
@@ -408,8 +446,11 @@ ipsec_spigrp_get_info(char *buffer,
 		      off_t offset,
 		      int length     IPSEC_PROC_LAST_ARG)
 {
+	/* Limit of useful snprintf output */
+	const int max_content = length > 0? length-1 : 0; 
+
 	int len = 0;
-	off_t pos = 0, begin = 0;
+	off_t begin = 0;
 	int i;
 	struct ipsec_sa *sa_p, *sa_p2;
 	char sa[SATOT_BUF];
@@ -438,36 +479,42 @@ ipsec_spigrp_get_info(char *buffer,
 					sa_len = satot(&sa_p2->ips_said,
 						       'x', sa, sizeof(sa));
 					
-					len += sprintf(buffer + len, "%s ",
+					len += ipsec_snprintf(buffer+len, length-len, "%s ",
 						       sa_len ? sa : " (error)");
 					atomic_dec(&sa_p2->ips_refcount);
 					sa_p2 = sa_p2->ips_onext;
 				}
-				len += sprintf(buffer + len, "\n");
-				pos = begin + len;
-				if(pos < offset) {
-					len = 0;
-					begin = pos;
-				}
-				if (pos > offset + length) {
-					atomic_dec(&sa_p->ips_refcount);
-					goto done_spigrp_i;
-				}
-			}
-			atomic_dec(&sa_p->ips_refcount);
+				len += ipsec_snprintf(buffer+len, length-len, "\n");
+                       }
+
+                       atomic_dec(&sa_p->ips_refcount);
+                                        
+                       if (len >= max_content) {
+                               /* we've done all that can fit -- stop loops */
+                               len = max_content;      /* truncate crap */
+                               goto done_spigrp_i;
+                       } else {
+                               const off_t pos = begin + len;
+
+                               if (pos <= offset) {
+                                       /* all is before first interesting character:
+                                        * discard, but note where we are.
+                                        */
+                                        len = 0;
+                                        begin = pos;
+                               }
+                       }
 		}
 	}
 
- done_spigrp_i:	
+done_spigrp_i:	
 	spin_unlock_bh(&tdb_lock);
 
 	*start = buffer + (offset - begin);	/* Start of wanted data */
-	len -= (offset - begin);			/* Start slop */
-	if (len > length)
-		len = length;
-	return len;
+	return len - (offset - begin);
 }
 
+
 IPSEC_PROCFS_DEBUG_NO_STATIC
 int
 ipsec_tncfg_get_info(char *buffer,
@@ -475,8 +522,10 @@ ipsec_tncfg_get_info(char *buffer,
 		     off_t offset,
 		     int length     IPSEC_PROC_LAST_ARG)
 {
+	/* limit of useful snprintf output */ 
+	const int max_content = length > 0? length-1 : 0;
 	int len = 0;
-	off_t pos = 0, begin = 0;
+	off_t begin = 0;
 	int i;
 	char name[9];
 	struct device *dev, *privdev;
@@ -491,17 +540,17 @@ ipsec_tncfg_get_info(char *buffer,
 		    length);
 
 	for(i = 0; i < IPSEC_NUM_IF; i++) {
-		sprintf(name, IPSEC_DEV_FORMAT, i);
+		ipsec_snprintf(name, (ssize_t) sizeof(name), IPSEC_DEV_FORMAT, i);
 		dev = __ipsec_dev_get(name);
 		if(dev) {
 			priv = (struct ipsecpriv *)(dev->priv);
-			len += sprintf(buffer + len, "%s",
+			len += ipsec_snprintf(buffer+len, length-len, "%s",
 				       dev->name);
 			if(priv) {
 				privdev = (struct device *)(priv->dev);
-				len += sprintf(buffer + len, " -> %s",
+				len += ipsec_snprintf(buffer+len, length-len, " -> %s",
 					       privdev ? privdev->name : "NULL");
-				len += sprintf(buffer + len, " mtu=%d(%d) -> %d",
+				len += ipsec_snprintf(buffer+len, length-len, " mtu=%d(%d) -> %d",
 					       dev->mtu,
 					       priv->mtu,
 					       privdev ? privdev->mtu : 0);
@@ -510,15 +559,18 @@ ipsec_tncfg_get_info(char *buffer,
 					    "klips_debug:ipsec_tncfg_get_info: device '%s' has no private data space!\n",
 					    dev->name);
 			}
-			len += sprintf(buffer + len, "\n");
+			len += ipsec_snprintf(buffer+len, length-len, "\n");
 
-			pos = begin + len;
-			if(pos < offset) {
-				len = 0;
-				begin = pos;
-			}
-			else if (pos > offset + length)	{
-				break;
+                        if (len >= max_content) {
+                                /* we've done all that can fit -- stop loop */
+                                len = max_content;      /* truncate crap */
+                                 break;
+                        } else {
+                                const off_t pos = begin + len;
+                                if (pos <= offset) {
+                                        len = 0;
+                                        begin = pos;
+                                }
 			}
 		}
 	}
@@ -547,7 +599,7 @@ ipsec_version_get_info(char *buffer,
 		    (int)offset,
 		    length);
 
-	len += sprintf(buffer + len, "FreeS/WAN version: %s\n",
+	len += ipsec_snprintf(buffer + len,length-len, "Openswan version: %s\n",
 		       ipsec_version_code());
 #if 0
 	KLIPS_PRINT(debug_tunnel & DB_TN_PROCFS,
@@ -568,6 +620,7 @@ ipsec_version_get_info(char *buffer,
 		    radij_c_version);
 #endif
 
+
 	*start = buffer + (offset - begin);	/* Start of wanted data */
 	len -= (offset - begin);			/* Start slop */
 	if (len > length)
@@ -650,15 +703,15 @@ ipsec_klipsdebug_get_info(char *buffer,
 		    (int)offset,
 		    length);
 
-	len += sprintf(buffer + len, "debug_tunnel=%08x.\n", debug_tunnel);
-	len += sprintf(buffer + len, "debug_xform=%08x.\n", debug_xform);
-	len += sprintf(buffer + len, "debug_eroute=%08x.\n", debug_eroute);
-	len += sprintf(buffer + len, "debug_spi=%08x.\n", debug_spi);
-	len += sprintf(buffer + len, "debug_radij=%08x.\n", debug_radij);
-	len += sprintf(buffer + len, "debug_esp=%08x.\n", debug_esp);
-	len += sprintf(buffer + len, "debug_ah=%08x.\n", debug_ah);
-	len += sprintf(buffer + len, "debug_rcv=%08x.\n", debug_rcv);
-	len += sprintf(buffer + len, "debug_pfkey=%08x.\n", debug_pfkey);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_tunnel=%08x.\n", debug_tunnel);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_xform=%08x.\n", debug_xform);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_eroute=%08x.\n", debug_eroute);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_spi=%08x.\n", debug_spi);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_radij=%08x.\n", debug_radij);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_esp=%08x.\n", debug_esp);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_ah=%08x.\n", debug_ah);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_rcv=%08x.\n", debug_rcv);
+	len += ipsec_snprintf(buffer+len, length-len, "debug_pfkey=%08x.\n", debug_pfkey);
 
 	*start = buffer + (offset - begin);	/* Start of wanted data */
 	len -= (offset - begin);			/* Start slop */
@@ -673,23 +726,25 @@ int
 ipsec_stats_get_int_info(char *buffer,
 			 char **start,
 			 off_t offset,
-			 int count,
-			 int *eof,
-			 void *data)
+			 int   length,
+			 int   *eof,
+			 void  *data)
 {
+
+	const int max_content = length > 0? length-1 : 0;
 	int len = 0;
-	off_t begin = 0;
 	int *thing;
 
 	thing = (int *)data;
 	
-	len += sprintf(buffer + len, "%08x\n", *thing);
+	len = ipsec_snprintf(buffer+len, length-len, "%08x\n", *thing);
+
+	if (len >= max_content)
+               len = max_content;      /* truncate crap */
+
+        *start = buffer + offset;       /* Start of wanted data */
+        return len > offset? len - offset : 0;
 
-	*start = buffer + (offset - begin);	/* Start of wanted data */
-	len -= (offset - begin);			/* Start slop */
-	if (len > count)
-		len = count;
-	return len;
 }
 
 #ifndef PROC_FS_2325
@@ -943,9 +998,32 @@ ipsec_proc_cleanup()
 
 /*
  * $Log: ipsec_proc.c,v $
+ * Revision 1.26.2.3  2004/05/01 04:46:26  ken
+ * Pull in snprintf() and proc fixes from HEAD.
+ * Remove old cvs comments
+ *
+ *
+ * Revision 1.30  2004/04/25 21:23:11  ken
+ * Pull in dhr's changes from FreeS/WAN 2.06
+ *
+ * Revision 1.29  2004/04/06 02:49:26  mcr
+ * 	pullup of algo code from alg-branch.
+ *
+ * Revision 1.28  2004/03/28 20:29:58  paul
+ *      <hugh_> ssize_t, not ssized_t
+ *
+ * Revision 1.27  2004/03/28 20:27:20  paul
+ * Included tested and confirmed fixes mcr made and dhr verified for
+ * snprint statements. Changed one other snprintf to use ipsec_snprintf
+ * so it wouldnt break compatibility with 2.0/2.2 kernels. Verified with
+ * dhr. (thanks dhr!)
+ *
  * Revision 1.26  2004/02/09 22:07:06  mcr
  * 	added information about nat-traversal setting to spi-output.
  *
+ * Revision 1.25.4.1  2004/04/05 04:30:46  mcr
+ * 	patches for alg-branch to compile/work with 2.x openswan
+ *
  * Revision 1.25  2003/10/31 02:27:55  mcr
  * 	pulled up port-selector patches and sa_id elimination.
  *
@@ -959,90 +1037,6 @@ ipsec_proc_cleanup()
  * Revision 1.23  2003/04/03 17:38:09  rgb
  * Centralised ipsec_kfree_skb and ipsec_dev_{get,put}.
  *
- * Revision 1.22  2002/09/20 15:40:57  rgb
- * Renamed saref macros for consistency and brevity.
- *
- * Revision 1.21  2002/09/20 05:01:35  rgb
- * Print ref and  reftable, refentry seperately.
- *
- * Revision 1.20  2002/09/19 02:35:39  mcr
- * 	do not define structures needed by /proc/net/ipsec/ if we
- * 	aren't going create that directory.
- *
- * Revision 1.19  2002/09/10 01:43:25  mcr
- * 	fixed problem in /-* comment.
- *
- * Revision 1.18  2002/09/03 16:22:11  mcr
- * 	fixed initialization of birth/stuff values - some simple
- * 	screw ups in the code.
- * 	removed debugging that was left in by mistake.
- *
- * Revision 1.17  2002/09/02 17:54:53  mcr
- * 	changed how the table driven /proc entries are created so that
- * 	making subdirs is now explicit rather than implicit.
- *
- * Revision 1.16  2002/08/30 01:23:37  mcr
- * 	reorganized /proc creating code to clear up ifdefs,
- * 	make the 2.4 code table driven, and put things into
- * 	/proc/net/ipsec subdir. Symlinks are left for compatibility.
- *
- * Revision 1.15  2002/08/13 19:01:25  mcr
- * 	patches from kenb to permit compilation of FreeSWAN on ia64.
- * 	des library patched to use proper DES_LONG type for ia64.
- *
- * Revision 1.14  2002/07/26 08:48:31  rgb
- * Added SA ref table code.
- *
- * Revision 1.13  2002/07/24 18:44:54  rgb
- * Type fiddling to tame ia64 compiler.
- *
- * Revision 1.12  2002/05/27 18:56:07  rgb
- * Convert to dynamic ipsec device allocation.
- *
- * Revision 1.11  2002/05/23 07:14:50  rgb
- * Added refcount code.
- * Cleaned up %p variants to 0p%p for test suite cleanup.
- * Convert "usecount" to "refcount" to remove ambiguity.
- *
- * Revision 1.10  2002/04/24 07:55:32  mcr
- * 	#include patches and Makefiles for post-reorg compilation.
- *
- * Revision 1.9  2002/04/24 07:36:28  mcr
- * Moved from ./klips/net/ipsec/ipsec_proc.c,v
- *
- * Revision 1.8  2002/01/29 17:17:55  mcr
- * 	moved include of ipsec_param.h to after include of linux/kernel.h
- * 	otherwise, it seems that some option that is set in ipsec_param.h
- * 	screws up something subtle in the include path to kernel.h, and
- * 	it complains on the snprintf() prototype.
- *
- * Revision 1.7  2002/01/29 04:00:52  mcr
- * 	more excise of kversions.h header.
- *
- * Revision 1.6  2002/01/29 02:13:17  mcr
- * 	introduction of ipsec_kversion.h means that include of
- * 	ipsec_param.h must preceed any decisions about what files to
- * 	include to deal with differences in kernel source.
- *
- * Revision 1.5  2002/01/12 02:54:30  mcr
- * 	beginnings of /proc/net/ipsec dir.
- *
- * Revision 1.4  2001/12/11 02:21:05  rgb
- * Don't include module version here, fixing 2.2 compile bug.
- *
- * Revision 1.3  2001/12/05 07:19:44  rgb
- * Fixed extraneous #include "version.c" bug causing modular KLIPS failure.
- *
- * Revision 1.2  2001/11/26 09:16:14  rgb
- * Merge MCR's ipsec_sa, eroute, proc and struct lifetime changes.
- *
- * Revision 1.74  2001/11/22 05:44:11  henry
- * new version stuff
- *
- * Revision 1.1.2.1  2001/09/25 02:19:40  mcr
- * 	/proc manipulation code moved to new ipsec_proc.c
- *
- *
  * Local variables:
  * c-file-style: "linux"
  * End:
