@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: constants.c,v 1.93.2.1 2004/03/21 05:23:32 mcr Exp $
+ * RCSID $Id: constants.c,v 1.93.2.3 2004/05/07 03:17:06 ken Exp $
  */
 
 /*
@@ -24,8 +24,8 @@
 #include <stdio.h>
 #include <netinet/in.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #include "constants.h"
 #include "defs.h"
@@ -400,6 +400,19 @@ static const char *const cert_type_name[] = {
 enum_names cert_type_names =
     { CERT_NONE, CERT_X509_ATTRIBUTE, cert_type_name, NULL };
 
+/*
+ * certificate request payload policy
+ */
+static const char *const certpolicy_type_name[] = {
+     "CERT_NEVERSEND",
+     "CERT_SENDIFASKED",
+     "CERT_ALWAYSSEND"
+};
+  	 
+enum_names certpolicy_type_names =
+     { cert_neversend, cert_alwayssend, certpolicy_type_name, NULL };
+  	 
+
 /* Goal BITs for establishing an SA
  * Note: we drop the POLICY_ prefix so that logs are more concise.
  */
