@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: dnskey.c,v 1.78.2.2 2004/03/21 05:23:32 mcr Exp $
+ * RCSID $Id: dnskey.c,v 1.78.2.3 2004/04/16 12:33:10 mcr Exp $
  */
 
 #include <stdlib.h>
@@ -29,8 +29,8 @@
 #include <netdb.h>	/* ??? for h_errno */
 #include <sys/queue.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #include "constants.h"
 #include "adns.h"	/* needs <resolv.h> */
