@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: kernel.c,v 1.198.2.2 2004/03/21 05:23:32 mcr Exp $
+ * RCSID $Id: kernel.c,v 1.198.2.3 2004/04/16 12:33:10 mcr Exp $
  */
 
 #include <stddef.h>
@@ -30,8 +30,8 @@
 #include <netinet/in.h>
 #include <arpa/inet.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #ifdef KLIPS
 #include <signal.h>
