@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: keys.c,v 1.88.4.1 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: keys.c,v 1.88.4.2 2004/04/16 12:33:10 mcr Exp $
  */
 
 #include <stddef.h>
@@ -33,8 +33,8 @@
 # define GLOB_ABORTED    GLOB_ABEND	/* fix for old versions */
 #endif
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #include "constants.h"
 #include "defs.h"
