@@ -11,10 +11,10 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: log.h,v 1.47.2.1 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: log.h,v 1.47.2.2 2004/04/16 12:33:10 mcr Exp $
  */
 
-#include <openswan.h>
+#include <freeswan.h>
 
 #define LOG_WIDTH   1024    /* roof of number of chars in log line */
 
@@ -23,7 +23,7 @@
 #endif
 
 /* moved common code to library file */
-#include "openswan/passert.h"
+#include "freeswan/passert.h"
 
 extern bool
     log_to_stderr,	/* should log go to stderr? */
