@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: nat_traversal.c,v 1.3.2.2 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: nat_traversal.c,v 1.3.2.4 2004/06/01 14:42:36 ken Exp $
  */
 
 #ifdef NAT_TRAVERSAL
@@ -27,8 +27,8 @@
 #include <signal.h>     /* used only if MSG_NOSIGNAL not defined */
 #include <sys/queue.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 #include <pfkeyv2.h>
 #include <pfkey.h>
 #include "constants.h"
@@ -80,6 +80,7 @@
 #endif
 
 bool nat_traversal_enabled = FALSE;
+bool nat_traversal_support_non_ike = FALSE;
 bool nat_traversal_support_port_floating = FALSE;
 
 static unsigned int _kap = 0;
@@ -92,6 +93,7 @@ void init_nat_traversal (bool activate, unsigned int keep_alive_period,
 	bool fka, bool spf)
 {
 	nat_traversal_enabled = activate;
+	nat_traversal_support_non_ike = activate;
 #ifdef NAT_T_SUPPORT_LAST_DRAFTS
 	nat_traversal_support_port_floating = activate ? spf : FALSE;
 #endif
@@ -103,10 +105,16 @@ void init_nat_traversal (bool activate, unsigned int keep_alive_period,
 		activate & !spf ? " [Port Floating disabled]" : "");
 }
 
-static void disable_nat_traversal (void)
+static void disable_nat_traversal(int type)
 {
-	nat_traversal_enabled = FALSE; 
-	nat_traversal_support_port_floating = FALSE;
+	if (type == ESPINUDP_WITH_NON_IKE)
+		nat_traversal_support_non_ike = FALSE;
+	else
+		nat_traversal_support_port_floating = FALSE;
+
+	if (!nat_traversal_support_non_ike &&
+	    !nat_traversal_support_port_floating)
+		nat_traversal_enabled = FALSE; 
 }
 
 static void _natd_hash(const struct hash_desc *hasher, char *hash,
@@ -176,7 +184,7 @@ bool nat_traversal_add_vid(u_int8_t np, pb_stream *outs)
 		if (r) r = out_vendorid(np, outs, VID_NATT_IETF_03);
 		if (r) r = out_vendorid(np, outs, VID_NATT_IETF_02);
 	}
-	if (kernel_ops->espinudp_with_non_ike) {
+	if (nat_traversal_support_non_ike) {
 		if (r) r = out_vendorid(np, outs, VID_NATT_IETF_00);
 	}
 	return r;
@@ -531,7 +539,7 @@ int nat_traversal_espinudp_socket (int sk, u_int32_t type)
 		loglog(RC_LOG_SERIOUS,
 			"NAT-Traversal: ESPINUDP(%d) not supported by kernel -- "
 			"NAT-T disabled", type);
-		disable_nat_traversal();
+		disable_nat_traversal(type);
 	}
 	return r;
 }
