@@ -12,7 +12,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: server.c,v 1.92.2.2 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: server.c,v 1.92.2.4 2004/06/02 12:42:44 ken Exp $
  */
 
 #include <stdio.h>
@@ -668,8 +668,7 @@ add_entry:
 		    }
 
 #ifdef NAT_TRAVERSAL
-		    if (nat_traversal_enabled
-		    && kernel_ops->espinudp_with_non_ike)
+		    if (nat_traversal_support_non_ike)
 		    {
 			nat_traversal_espinudp_socket(fd, ESPINUDP_WITH_NON_IKE);
 		    }
