@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: spdb.c,v 1.98.2.1 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: spdb.c,v 1.98.2.2 2004/04/16 12:33:10 mcr Exp $
  */
 
 #include <stdio.h>
@@ -22,8 +22,8 @@
 #include <arpa/inet.h>
 #include <sys/queue.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #include "constants.h"
 #include "defs.h"
