@@ -11,7 +11,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: vendor.c,v 1.5.2.2 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: vendor.c,v 1.5.2.3 2004/06/01 14:42:36 ken Exp $
  */
 
 #include <stdlib.h>
@@ -301,7 +301,7 @@ static void handle_known_vendorid (struct msg_digest *md UNUSED,
 		 * Note: most recent == higher id in vendor.h
 		 */
 		case VID_NATT_IETF_00:
-			if (!kernel_ops->espinudp_with_non_ike)
+			if (!nat_traversal_support_non_ike)
 			    break;
 			vid_usefull = 1;
 			if ((nat_traversal_enabled) && (!md->quirks.nat_traversal_vid)) {
