@@ -13,7 +13,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: whack.c,v 1.120.2.1 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: whack.c,v 1.120.2.2 2004/06/01 14:42:36 ken Exp $
  */
 
 #include <stdio.h>
@@ -73,7 +73,7 @@ help(void)
 	    " --to"
 	    " (--host <ip-address> | --id <identity> | --cert <path>)"
 	    " [--ca <distinguished name>]"
-	    " [--sendcert]"
+	    " [--sendcert yes|always|no|never|ifasked]"
 	    " [--ikeport <port-number>]"
 	    " \\\n   "
 	    " [--nexthop <ip-address>]"
