@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: x509.c,v 1.6.2.1 2004/03/21 05:23:34 mcr Exp $
+ * RCSID $Id: x509.c,v 1.6.2.4 2004/06/17 00:35:21 ken Exp $
  */
 
 #include <stdlib.h>
@@ -25,8 +25,8 @@
 #include <time.h>
 #include <sys/types.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 
 #include <sys/queue.h>
 
@@ -1767,12 +1767,10 @@ load_crls(void)
 		if (load_coded_file(filename, NULL, "crl", &blob, &pgp))
 		{
 		    chunk_t crl_uri;
-		    crl_uri.len = 7 + sizeof(CRL_PATH) + strlen(filename);
+                    crl_uri.len = 8 + strlen(CRL_PATH) + strlen(filename);
 		    crl_uri.ptr = alloc_bytes(crl_uri.len + 1, "crl uri");
-
 		    /* build CRL file URI */
-		    sprintf(crl_uri.ptr, "file://%s/%s", CRL_PATH, filename);
-
+		    snprintf(crl_uri.ptr, crl_uri.len +1, "file://%s/%s", CRL_PATH, filename);
 		    insert_crl(blob, crl_uri);
 		}
 		free(filelist[n]);
@@ -2378,6 +2376,13 @@ verify_x509cert(const x509cert_t *cert, bool strict, time_t *until)
 
     *until = cert->notAfter;
 
+if (same_dn(cert->issuer, cert->subject))
+    {
+	plog("end certificate with identical subject and issuer not accepted");
+	return FALSE;
+    }
+
+
     do
     {
 	err_t ugh = NULL;
