@@ -14,7 +14,7 @@
  * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
  * for more details.
  *
- * RCSID $Id: xauth.c,v 1.15.2.1 2004/03/21 05:23:35 mcr Exp $
+ * RCSID $Id: xauth.c,v 1.15.2.3 2004/05/11 16:35:30 ken Exp $
  *
  * This code originally written by Colubris Networks, Inc.
  * Extraction of patch and porting to 1.99 codebases by Xelerance Corporation
@@ -34,8 +34,8 @@
 #include <sys/queue.h>
 #include <crypt.h>
 
-#include <openswan.h>
-#include <openswan/ipsec_policy.h>
+#include <freeswan.h>
+#include <freeswan/ipsec_policy.h>
 #include "constants.h"
 #include "defs.h"
 #include "state.h"
